@@ -10,10 +10,12 @@ use warnings;
 
 use utf8;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Carp;
 
+require Device::Chip;
+
 =encoding UTF-8
 
 =head1 NAME
@@ -96,8 +98,7 @@ sub new_from_description
       croak "Malformed adapter description - $description";
 
    # Not a hash, in case the same option is given more than once
-   my @opts = map { m/^([^=]+)=(.*)$/ ? ( $1 => $2 ) : ( $_ => 1 ) }
-              split m/,/, $opts // "";
+   my @opts = Device::Chip->_parse_options( $opts );
 
    my $class = "Device::Chip::Adapter::$basename";
    ( my $file = "$class.pm" ) =~ s{::}{/}g;
@@ -131,6 +132,7 @@ Returns an object that satisfies one of the interfaces documented below in
 L</PROTOCOLS>, depending on the protocol name given by I<$pname>. This should
 be one of the following values:
 
+   GPIO
    SPI
    I2C
 
@@ -192,8 +194,48 @@ apply multiple changes in one go.
 Switches on or off the power to the actual chip or module, if such ability is
 provided by the adapter.
 
+=head2 list_gpios
+
+   @pin_names = $protocol->list_gpios
+
+Returns a list of the names of GPIO pins that are available for the chip
+driver to use. This list would depend on the pins available on the adapter
+itself, minus any pins that are in use by the protocol itself.
+
+Adapters should name GPIO pins in a way that makes sense from the hardware;
+for example C<MOSI>, C<SDA>, C<DTR>, C<Q0>, etc...
+
+=head2 write_gpios
+
+   $protocol->write_gpios( \%pin_values )->get
+
+Sets the named GPIO pins as driven outputs, and gives their new values. Any
+GPIO pins not named are left as they are; either driving outputs at the
+current state, or high-impedence inputs.
+
+Pins are specified as a C<HASH> reference, mapping pin names (as returned by
+the L</list_gpios> method) to boolean logic levels.
+
+=head2 read_gpios
+
+   \%pin_values = $protocol->read_gpios( \@pin_names )->get;
+
+Sets the named GPIO pins as high-impedence inputs, and reads their current
+state. Any GPIO pins not named here are left as they are; either driving
+outputs at the current state, or other inputs.
+
+Pins are specified in an C<ARRAY> reference giving the names of pins (as
+returned by the L</list_gpios> method); read values are given in the returned
+C<HASH> reference which maps pin names to boolean logic levels.
+
 =cut
 
+=head1 GPIO PROTOCOL
+
+The GPIO protocol adds no new abilities or methods; it is the most basic form
+of protocol that simply provides access to the generic GPIO pins of the
+device.
+
 =head1 SPI PROTOCOL
 
 =head2 Configuration Options
